@@ -44,7 +44,7 @@ class ValidatedJSONField(JSONField):
 
     @cached_property
     def _get_default(self):
-        obj = {}
+        obj = [] if self.isArray else {}
         if(self.json_validator_cls):
             self.json_validator_cls.validate(obj)
         return lambda: obj
@@ -64,10 +64,16 @@ class ValidatedJSONField(JSONField):
         else:
             self.json_validator_cls = None
 
-        if(default is not None):
-            print("#WARNING# ValidatedJSONField: default argument is not allowed, as default is taken from schema", default)
+        self.isArray = False
+        if(self.schema is not None):
+            if(default==list or default==[]):
+                self.isArray=True
+            elif(default==dict or default=={}):
+                seld.isArray=False
+            elif(default is not None):
+                print("#WARNING# ValidatedJSONField: default argument is not allowed, as default is taken from schema", default)
 
-        if(blank):
-            print("#WARNING# ValidatedJSONField: blank argument can't be set to True otherwise validation is not run")
+            if(None and blank):
+                print("#WARNING# ValidatedJSONField: blank argument can't be set to True otherwise validation is not run")
 
         super().__init__(*args, blank=False, default=None, **kwargs)
